Lecture 1: Course Overview | CS184.1x Courseware | edX

Skip to main content
Help

## edX Help

For questions on course lectures, homework, tools, or materials for this course, post in the course discussion forum.

Have general questions about edX? You can find lots of helpful information in the edX FAQ.

Have a question about something specific? You can contact the edX general support team directly:

Report a problem Make a suggestion Ask a question

Please note: The edX support team is English speaking. While we will do our best to address your inquiry in any language, our responses will be in English.

Briefly describe your issue* Tell us the details* Include error messages, steps which lead to the issue, etc

## Thank You!

Thank you for your inquiry or feedback. We typically respond to a request within one business day (Monday to Friday, 13:00 UTC to 21:00 UTC.) In the meantime, please review our detailed FAQs where most questions have already been answered.

<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="725e38ba113011e585440a5fd5d593bd" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_vertical;_vertical_a62d06fd241f" data-block-type="vertical" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <div class="vert-mod"> <div class="vert vert-0" data-id="i4x://BerkeleyX/CS184.1x/video/L1V1_Online_Graphics_Overview_Motivation"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="725e38ba113011e585440a5fd5d593bd" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_video;_L1V1_Online_Graphics_Overview_Motivation" data-type="Video" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>L1V1: Online Graphics Overview: Motivation</h2> <div id="video_i4x-BerkeleyX-CS184_1x-video-L1V1_Online_Graphics_Overview_Motivation" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS184.1x/2012_Fall/xblock/i4x:;_;_BerkeleyX;_CS184.1x;_video;_L1V1_Online_Graphics_Overview_Motivation/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://s3.amazonaws.com/berkeley-cs184x/videos/overview-motivation.mp4"], "autohideHtml5": false, "streams": "0.75:FRgmzHQ62ck,1.00:CJ482b9r_0g,1.25:fULVrZ9b3_0,1.50:-d6AJA2I9u8", "saveStateUrl": "/courses/BerkeleyX/CS184.1x/2012_Fall/xblock/i4x:;_;_BerkeleyX;_CS184.1x;_video;_L1V1_Online_Graphics_Overview_Motivation/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS184.1x/2012_Fall/xblock/i4x:;_;_BerkeleyX;_CS184.1x;_video;_L1V1_Online_Graphics_Overview_Motivation/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS184_1x-video-L1V1_Online_Graphics_Overview_Motivation" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS184_1x-video-L1V1_Online_Graphics_Overview_Motivation"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS184_1x-video-L1V1_Online_Graphics_Overview_Motivation" href="#after-transcript_i4x-BerkeleyX-CS184_1x-video-L1V1_Online_Graphics_Overview_Motivation">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS184_1x-video-L1V1_Online_Graphics_Overview_Motivation" href="#before-transcript_i4x-BerkeleyX-CS184_1x-video-L1V1_Online_Graphics_Overview_Motivation">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://s3.amazonaws.com/berkeley-cs184x/videos/overview-motivation.mp4">Download video</a> </li> </ul> </div> </div> </div> <div class="vert vert-1" data-id="i4x://BerkeleyX/CS184.1x/html/video_l1v1"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="725e38ba113011e585440a5fd5d593bd" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_html;_video_l1v1" data-type="HTMLModule" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <body><a href="https://s3.amazonaws.com/berkeley-cs184x/transcripts/overview-motivation.txt">Video Transcript</a><br/><a href="https://s3.amazonaws.com/berkeley-cs184x/videos/overview-motivation_640.mp4">Low Resolution Video</a></body> </div> </div> <div class="vert vert-2" data-id="i4x://BerkeleyX/CS184.1x/html/video_l1"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="725e38ba113011e585440a5fd5d593bd" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_html;_video_l1" data-type="HTMLModule" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <body><a href="/static/content-berkeley-cs184x~2012_Fall/slides/overview.pdf">L1: Overview PDF Slides</a></body> </div> </div> <div class="vert vert-3" data-id="i4x://BerkeleyX/CS184.1x/discussion/discussion_20075626a5ab"> <div class="xblock xblock-student_view xblock-student_view-discussion xmodule_display xmodule_DiscussionModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="discussion" data-request-token="725e38ba113011e585440a5fd5d593bd" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_discussion;_discussion_20075626a5ab" data-type="InlineDiscussion" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "InlineDiscussion"} </script> <script aria-hidden="true" type="text/template" id="thread-template"> <article class="discussion-article" data-id="<%- id %>"> <div class="thread-wrapper" tabindex="-1"> <div class="forum-thread-main-wrapper"> <div class="thread-content-wrapper"></div> <div class="post-extended-content"> <ol class="responses js-marked-answer-list"></ol> </div> </div> <div class="post-extended-content"> <div class="response-count"/> <div class="add-response"> <button class="button add-response-btn"> <i class="icon fa fa-reply"></i> <span class="add-response-btn-text">Add A Response</span> </button> </div> <ol class="responses js-response-list"/> <div class="response-pagination"/> <div class="post-status-closed bottom-post-status" style="display: none"> This thread is closed. </div> <form class="discussion-reply-new" data-id="<%- id %>"> <h4>Post a response:</h4> <ul class="discussion-errors"></ul> <div class="reply-body" data-id="<%- id %>"></div> <div class="reply-post-control"> <a class="discussion-submit-post control-button" href="#">Submit</a> </div> </form> </div> </div> <div class="post-tools"> <a href="javascript:void(0)" class="forum-thread-expand"><span class="icon fa fa-plus"/> Expand discussion</a> <a href="javascript:void(0)" class="forum-thread-collapse"><span class="icon fa fa-minus"/> Collapse discussion</a> </div> </article> </script> <script aria-hidden="true" type="text/template" id="thread-show-template"> <div class="discussion-post"> <header> <div class="group-visibility-label"> <% if (obj.group_name) { %> <%- interpolate( gettext('This post is visible only to %(group_name)s.'), {group_name: obj.group_name}, true ) %> <% } else { %> <%- gettext('This post is visible to everyone.') %> <% } %> </div> <div class="post-header-content"> <h1><%- title %></h1> <p class="posted-details"> <% var timeAgoHtml = interpolate( '<span class="timeago" title="%(created_at)s">%(created_at)s</span>', {created_at: created_at}, true ); %> <%= interpolate( // Translators: post_type describes the kind of post this is (e.g. "question" or "discussion"); // time_ago is how much time has passed since the post was created (e.g. "4 hours ago") _.escape(gettext('%(post_type)s posted %(time_ago)s by %(author)s')), {post_type: thread_type, time_ago: timeAgoHtml, author: author_display}, true ) %> </p> <div class="post-labels"> <span class="post-label-pinned"><i class="icon fa fa-thumb-tack"></i><%- gettext("Pinned") %></span> <span class="post-label-reported"><i class="icon fa fa-flag"></i><%- gettext("Reported") %></span> <span class="post-label-closed"><i class="icon fa fa-lock"></i><%- gettext("Closed") %></span> </div> </div> <div class="post-header-actions post-extended-content"> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'post', primaryActions: ['vote', 'follow'], secondaryActions: ['pin', 'edit', 'delete', 'report', 'close'] } ) %> </div> </header> <div class="post-body"><%- body %></div> <% if (mode == "tab" && obj.courseware_url) { %> <% var courseware_title_linked = interpolate( '<a href="%(courseware_url)s">%(courseware_title)s</a>', {courseware_url: courseware_url, courseware_title: _.escape(courseware_title)}, true ); %> <div class="post-context"> <%= interpolate( _.escape(gettext('Related to: %(courseware_title_linked)s')), {courseware_title_linked: courseware_title_linked}, true ) %> </div> <% } %> </div> </script> <script aria-hidden="true" type="text/template" id="thread-edit-template"> <h1>Editing post</h1> <ul class="post-errors"></ul> <div class="forum-edit-post-form-wrapper"></div> <div class="form-row"> <label class="sr" for="edit-post-title">Edit post title</label> <input type="text" id="edit-post-title" class="edit-post-title" name="title" value="<%-title %>" placeholder="Title"> </div> <div class="form-row"> <div class="edit-post-body" name="body"><%- body %></div> </div> <input type="submit" id="edit-post-submit" class="post-update" value="Update post"> <a href="#" class="post-cancel">Cancel</a> </script> <script aria-hidden="true" type="text/template" id="thread-response-template"> <div class="discussion-response"></div> <a href="#" class="action-show-comments"> <%- interpolate('Show Comments (%(num_comments)s)', {num_comments: comments.length}, true) %> <i class="icon fa fa-caret-down"></i> </a> <ol class="comments"> <li class="new-comment"> <form class="comment-form" data-id="<%- wmdId %>"> <ul class="discussion-errors"></ul> <label class="sr" for="add-new-comment">Add a comment</label> <div class="comment-body" id="add-new-comment" data-id="<%- wmdId %>" data-placeholder="Add a comment"></div> <div class="comment-post-control"> <a class="discussion-submit-comment control-button" href="#">Submit</a> </div> </form> </li> </ol> </script> <script aria-hidden="true" type="text/template" id="thread-response-show-template"> <header> <div class="response-header-content"> <%= author_display %> <p class="posted-details"> <span class="timeago" title="<%= created_at %>"><%= created_at %></span> <% if (obj.endorsement) { %> - <%= interpolate( thread.get("thread_type") == "question" ? (endorsement.username ? "marked as answer %(time_ago)s by %(user)s" : "marked as answer %(time_ago)s") : (endorsement.username ? "endorsed %(time_ago)s by %(user)s" : "endorsed %(time_ago)s"), { 'time_ago': '<span class="timeago" title="' + endorsement.time + '">' + endorsement.time + '</span>', 'user': endorser_display }, true )%><% } %> </p> <div class="post-labels"> <span class="post-label-reported"><i class="icon fa fa-flag"></i>Reported</span> </div> </div> <div class="response-header-actions"> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'response', primaryActions: ['vote', thread.get('thread_type') == 'question' ? 'answer' : 'endorse'], secondaryActions: ['edit', 'delete', 'report'] } ) %> </div> </header> <div class="response-body"><%- body %></div> </script> <script aria-hidden="true" type="text/template" id="thread-response-edit-template"> <div class="edit-post-form"> <h1>Editing response</h1> <ul class="edit-post-form-errors"></ul> <div class="form-row"> <div class="edit-post-body" name="body" data-id="<%- id %>"><%- body %></div> </div> <input type="submit" id="edit-response-submit"class="post-update" value="Update response"> <a href="#" class="post-cancel">Cancel</a> </div> </script> <script aria-hidden="true" type="text/template" id="response-comment-show-template"> <div id="comment_<%- id %>"> <div class="response-body"><%- body %></div> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'comment', primaryActions: [], secondaryActions: ['edit', 'delete', 'report'] } ) %> <p class="posted-details"> <%= interpolate( 'posted %(time_ago)s by %(author)s', {'time_ago': '<span class="timeago" title="' + created_at + '">' + created_at + '</span>', 'author': author_display}, true )%> </p> <div class="post-labels"> <span class="post-label-reported"><i class="icon fa fa-flag"></i>Reported</span> </div> </div> </script> <script aria-hidden="true" type="text/template" id="response-comment-edit-template"> <div class="edit-post-form" id="comment_<%- id %>"> <h1>Editing comment</h1> <ul class="edit-comment-form-errors"></ul> <div class="form-row"> <div class="edit-comment-body" name="body" data-id="<%- id %>"><%- body %></div> </div> <input type="submit" id="edit-comment-submit" class="post-update" value="Update comment"> <a href="#" class="post-cancel">Cancel</a> </div> </script> <script aria-hidden="true" type="text/template" id="thread-list-item-template"> <li data-id="<%- id %>" class="forum-nav-thread<% if (typeof(read) != "undefined" && !read) { %> is-unread<% } %>"> <a href="#" class="forum-nav-thread-link"> <div class="forum-nav-thread-wrapper-0"> <% var icon_class, sr_text; if (thread_type == "discussion") { icon_class = "fa-comments"; sr_text = "discussion"; } else if (endorsed) { icon_class = "fa-check-square-o"; sr_text = "answered question"; } else { icon_class = "fa-question"; sr_text = "unanswered question"; } %> <span class="sr"><%= sr_text %></span> <i class="icon fa <%= icon_class %>"></i> </div><div class="forum-nav-thread-wrapper-1"> <span class="forum-nav-thread-title"><%- title %></span> <% var labels = ""; if (pinned) { labels += '<li class="post-label-pinned"><i class="icon fa fa-thumb-tack"></i>Pinned</li> '; } if (typeof(subscribed) != "undefined" && subscribed) { labels += '<li class="post-label-following"><i class="icon fa fa-star"></i>Following</li> '; } if (staff_authored) { labels += '<li class="post-label-by-staff"><i class="icon fa fa-user"></i>By: Staff</li> '; } if (community_ta_authored) { labels += '<li class="post-label-by-community-ta"><i class="icon fa fa-user"></i>By: Community TA</li> '; } if (labels != "") { print('<ul class="forum-nav-thread-labels">' + labels + '</ul>'); } %> </div><div class="forum-nav-thread-wrapper-2"> <span class="forum-nav-thread-votes-count">+<%= interpolate( '%(votes_up_count)s%(span_sr_open)s votes %(span_close)s', {'span_sr_open': '<span class="sr">', 'span_close': '</span>', 'votes_up_count': votes['up_count']}, true ) %></span> <span class="forum-nav-thread-comments-count <% if (unread_comments_count > 0) { %>is-unread<% } %>"> <% var fmt; // Counts in data do not include the post itself, but the UI should var data = { 'span_sr_open': '<span class="sr">', 'span_close': '</span>', 'unread_comments_count': unread_comments_count + (read ? 0 : 1), 'comments_count': comments_count + 1 }; if (unread_comments_count > 0) { fmt = '%(comments_count)s %(span_sr_open)scomments (%(unread_comments_count)s unread comments)%(span_close)s'; } else { fmt = '%(comments_count)s %(span_sr_open)scomments %(span_close)s'; } print(interpolate(fmt, data, true)); %> </span> </div> </a> </li> </script> <script aria-hidden="true" type="text/template" id="discussion-home"> <div class="discussion-article blank-slate"> <section class="home-header"> <span class="label">DISCUSSION HOME:</span> <h1 class="home-title">Foundations of Computer Graphics</h1> </section> <span class="label label-settings"> How to use edX discussions </span> <table class="home-helpgrid"> <tr class="helpgrid-row helpgrid-row-navigation"> <td class="row-title">Find discussions</td> <td class="row-item"> <i class="icon fa fa-reorder"></i> <span class="row-description">Focus in on specific topics</span> </td> <td class="row-item"> <i class="icon fa fa-search"></i> <span class="row-description">Search for specific posts </span> </td> <td class="row-item"> <i class="icon fa fa-sort"></i> <span class="row-description">Sort by date, vote, or comments</span> </td> </tr> <tr class="helpgrid-row helpgrid-row-participation"> <td class="row-title">Engage with posts</td> <td class="row-item"> <i class="icon fa fa-plus"></i> <span class="row-description">Upvote posts and good responses</span> </td> <td class="row-item"> <i class="icon fa fa-flag"></i> <span class="row-description">Report Forum Misuse</span> </td> <td class="row-item"> <i class="icon fa fa-star"></i> <span class="row-description">Follow posts for updates</span> </td> </tr> <tr class="helpgrid-row helpgrid-row-notification"> <td class="row-title">Receive updates</td> <td class="row-item-full" colspan="3"> <label for="email-setting-checkbox"> <span class="sr">Toggle Notifications Setting</span> <span class="notification-checkbox"> <input type="checkbox" id="email-setting-checkbox" class="email-setting" name="email-notification"/> <i class="icon fa fa-envelope"></i> </span> </label> <span class="row-description">Check this box to receive an email digest once a day notifying you about new, unread activity from posts you are following.</span> </td> </tr> </table> </div> </script> <script aria-hidden="true" type="text/template" id="search-alert-template"> <div class="search-alert" id="search-alert-<%- cid %>"> <div class="search-alert-content"> <p class="message"><%= message %></p> </div> <div class="search-alert-controls"> <a href="#" class="dismiss control control-dismiss"><i class="icon fa fa-remove"></i></a> </div> </div> </script> <script aria-hidden="true" type="text/template" id="new-post-template"> <form class="forum-new-post-form"> <ul class="post-errors" style="display: none"></ul> <div class="forum-new-post-form-wrapper"></div> <% if (cohort_options) { %> <div class="post-field group-selector-wrapper<% if (!is_commentable_cohorted) { %> disabled<% } %>" > <label class="field-label"> <span class="field-label-text"> Visible To: </span><select aria-describedby="field_help_visible_to" class="field-input js-group-select" name="group_id" <% if (!is_commentable_cohorted) { %>disabled<% } %>> <option value="">All Groups</option> <% _.each(cohort_options, function(opt) { %> <option value="<%= opt.value %>" <% if (opt.selected) { %>selected<% } %>><%- opt.text %></option> <% }); %> </select> </label><div class="field-help" id="field_help_visible_to"> Discussion admins, moderators, and TAs can make their posts visible to all students or specify a single cohort. </div> </div> <% } %> <div class="post-field"> <label class="field-label"> <span class="sr">Title:</span> <input aria-describedby="field_help_title" type="text" class="field-input js-post-title" name="title" placeholder="Title"> </label><span class="field-help" id="field_help_title"> Add a clear and descriptive title to encourage participation. </span> </div> <div class="post-field js-post-body editor" name="body" data-placeholder="Enter your question or comment"></div> <div class="post-options"> <label class="post-option is-enabled"> <input type="checkbox" name="follow" class="post-option-input js-follow" checked> <i class="icon fa fa-star"></i>follow this post </label> <% if (allow_anonymous) { %> <label class="post-option"> <input type="checkbox" name="anonymous" class="post-option-input js-anon"> post anonymously </label> <% } %> <% if (allow_anonymous_to_peers) { %> <label class="post-option"> <input type="checkbox" name="anonymous_to_peers" class="post-option-input js-anon-peers"> post anonymously to classmates </label> <% } %> </div> <div> <input type="submit" class="submit" value="Add Post"> <a href="#" class="cancel">Cancel</a> </div> </form> </script> <script aria-hidden="true" type="text/template" id="thread-type-template"> <div class="post-field"> <div class="field-label"> <span class="field-label-text"> Post type: </span><fieldset class="field-input"><legend class="sr">Post type:</legend> <input aria-describedby="field_help_post_type" type="radio" name="<%= form_id %>-post-type" class="post-type-input" id="<%= form_id %>-post-type-question" value="question"> <label for="<%= form_id %>-post-type-question" class="post-type-label"> <i class="icon fa fa-question"></i> Question </label> <input aria-describedby="field_help_post_type" type="radio" name="<%= form_id %>-post-type" class="post-type-input" id="<%= form_id %>-post-type-discussion" value="discussion" checked> <label for="<%= form_id %>-post-type-discussion" class="post-type-label"> <i class="icon fa fa-comments"></i> Discussion </label> </fieldset> </div><span class="field-help" id="field_help_post_type"> Questions raise issues that need answers. Discussions share ideas and start conversations. </span> </div> </script> <script aria-hidden="true" type="text/template" id="new-post-menu-entry-template"> <li role="menuitem" class="topic-menu-item"> <a href="#" class="topic-title" data-discussion-id="<%- id %>" data-cohorted="<%- is_cohorted %>"><%- text %></a> </li> </script> <script aria-hidden="true" type="text/template" id="new-post-menu-category-template"> <li role="menuitem" class="topic-menu-item"> <span class="topic-title"><%- text %></span> <ul role="menu" class="topic-submenu"><%= entries %></ul> </li> </script> <script aria-hidden="true" type="text/template" id="topic-template"> <div class="field-label"> <span class="field-label-text">Topic Area:</span><div class="field-input post-topic"> <a href="#" class="post-topic-button"> <span class="sr">Discussion topics; current selection is: </span> <span class="js-selected-topic"></span> <span class="drop-arrow" aria-hidden="true">▾</span> </a> <div class="topic-menu-wrapper"> <label class="topic-filter-label"> <span class="sr">Filter topics</span> <input aria-describedby="field_help_topic_area" type="text" class="topic-filter-input" placeholder="Filter topics"> </label> <ul class="topic-menu" role="menu"><%= topics_html %></ul> </div> </div> </div><span class="field-help" id="field_help_topic_area"> Add your post to a relevant topic to help others find it. </span> </script> <script type="text/template" id="forum-action-endorse"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-endorse" role="checkbox" aria-checked="false"> <span class="sr">Endorse</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Endorse</span> <span class="label-checked">Unendorse</span> </span> <span class="action-icon"><i class="icon fa fa-check"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-answer"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-answer" role="checkbox" aria-checked="false"> <span class="sr">Mark as Answer</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Mark as Answer</span> <span class="label-checked">Unmark as Answer</span> </span> <span class="action-icon"><i class="icon fa fa-check"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-follow"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-follow" role="checkbox" aria-checked="false"> <span class="sr">Follow</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Follow</span> <span class="label-checked">Unfollow</span> </span> <span class="action-icon"><i class="icon fa fa-star"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-vote"> <li class="actions-item"> <span aria-hidden="true" class="display-vote" > <span class="vote-count"></span> </span> <a href="#" class="action-button action-vote" role="checkbox" aria-checked="false"> <span class="sr">Vote for this post,&nbsp;</span> <span class="sr js-sr-vote-count"></span> <span class="action-label" aria-hidden="true"> <span class="vote-count"></span> </span> <span class="action-icon" aria-hidden="true"> <i class="icon fa fa-plus"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-report"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-report" role="checkbox" aria-checked="false"> <span class="sr">Report abuse</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Report</span> <span class="label-checked">Unreport</span> </span> <span class="action-icon"> <i class="icon fa fa-flag"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-pin"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-pin" role="checkbox" aria-checked="false"> <span class="sr">Pin</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Pin</span> <span class="label-checked">Unpin</span> </span> <span class="action-icon"> <i class="icon fa fa-thumb-tack"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-close"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-close" role="checkbox" aria-checked="false"> <span class="sr">Close</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Close</span> <span class="label-checked">Open</span> </span> <span class="action-icon"> <i class="icon fa fa-lock"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-edit"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-edit" role="button"> <span class="action-label">Edit</span> <span class="action-icon"><i class="icon fa fa-pencil"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-delete"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-delete" role="button"> <span class="action-label">Delete</span> <span class="action-icon"><i class="icon fa fa-remove"></i></span> </a> </li> </script> <script type="text/template" id="forum-actions"> <ul class="<%= contentType %>-actions-list"> <% _.each(primaryActions, function(action) { print(_.template($('#forum-action-' + action).html(), {})) }) %> <li class="actions-item is-visible"> <div class="more-wrapper"> <a href="javascript:void(0)" class="action-button action-more" role="button" aria-haspopup="true" aria-controls="action-menu-<%= contentId %>"> <span class="action-label">More</span> <span class="action-icon"><i class="icon fa fa-ellipsis-h"></i></span> </a> <div class="actions-dropdown" id="action-menu-<%= contentType %>" aria-expanded="false"> <ul class="actions-dropdown-list"> <% _.each(secondaryActions, function(action) { print(_.template($('#forum-action-' + action).html(), {})) }) %> </ul> </div> </div> </li> </ul> </script> <script aria-hidden="true" type="text/template" id="post-user-display-template"> <% if (username) { %> <a href="<%- user_url %>" class="username"><%- username %></a> <% if (is_community_ta) { %> <span class="user-label-community-ta">Community TA</span> <% } else if (is_staff) { %> <span class="user-label-staff">Staff</span> <% } %> <% } else { %> anonymous <% } %> </script> <div class="discussion-module" data-discussion-id="CS184_1x_2012_Fall_L1V1"> <a class="discussion-show control-button" href="javascript:void(0)" data-discussion-id="CS184_1x_2012_Fall_L1V1" role="button"><span class="show-hide-discussion-icon"></span><span class="button-text">Show Discussion</span></a> <a href="#" class="new-post-btn" role="button"><span class="icon fa fa-edit new-post-icon"></span>New Post</a> </div> </div> </div> </div> </div>
<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="725e38ba113011e585440a5fd5d593bd" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_vertical;_vertical_5fc6ceb3e442" data-block-type="vertical" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <div class="vert-mod"> <div class="vert vert-0" data-id="i4x://BerkeleyX/CS184.1x/video/L1V2_Online_Graphics_Overview_Course_Outline_and_Logistics"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="725e38ba113011e585440a5fd5d593bd" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_video;_L1V2_Online_Graphics_Overview_Course_Outline_and_Logistics" data-type="Video" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>L1V2: Online Graphics Overview: Course Outline and Logistics</h2> <div id="video_i4x-BerkeleyX-CS184_1x-video-L1V2_Online_Graphics_Overview_Course_Outline_and_Logistics" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS184.1x/2012_Fall/xblock/i4x:;_;_BerkeleyX;_CS184.1x;_video;_L1V2_Online_Graphics_Overview_Course_Outline_and_Logistics/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://s3.amazonaws.com/berkeley-cs184x/videos/overview-logistics.mp4"], "autohideHtml5": false, "streams": "0.75:wbTseJOXp7M,1.00:M1jxGJWET-Y,1.25:4rb0DIlesOg,1.50:6Cmzw2RPF7A", "saveStateUrl": "/courses/BerkeleyX/CS184.1x/2012_Fall/xblock/i4x:;_;_BerkeleyX;_CS184.1x;_video;_L1V2_Online_Graphics_Overview_Course_Outline_and_Logistics/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS184.1x/2012_Fall/xblock/i4x:;_;_BerkeleyX;_CS184.1x;_video;_L1V2_Online_Graphics_Overview_Course_Outline_and_Logistics/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS184_1x-video-L1V2_Online_Graphics_Overview_Course_Outline_and_Logistics" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS184_1x-video-L1V2_Online_Graphics_Overview_Course_Outline_and_Logistics"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS184_1x-video-L1V2_Online_Graphics_Overview_Course_Outline_and_Logistics" href="#after-transcript_i4x-BerkeleyX-CS184_1x-video-L1V2_Online_Graphics_Overview_Course_Outline_and_Logistics">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS184_1x-video-L1V2_Online_Graphics_Overview_Course_Outline_and_Logistics" href="#before-transcript_i4x-BerkeleyX-CS184_1x-video-L1V2_Online_Graphics_Overview_Course_Outline_and_Logistics">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://s3.amazonaws.com/berkeley-cs184x/videos/overview-logistics.mp4">Download video</a> </li> </ul> </div> </div> </div> <div class="vert vert-1" data-id="i4x://BerkeleyX/CS184.1x/html/video_l1v2"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="725e38ba113011e585440a5fd5d593bd" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_html;_video_l1v2" data-type="HTMLModule" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <body><a href="https://s3.amazonaws.com/berkeley-cs184x/transcripts/overview-logistics.txt">Video Transcript</a><br/><a href="https://s3.amazonaws.com/berkeley-cs184x/videos/overview-logistics_640.mp4">Low Resolution Video</a></body> </div> </div> <div class="vert vert-2" data-id="i4x://BerkeleyX/CS184.1x/html/video_l1"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="725e38ba113011e585440a5fd5d593bd" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_html;_video_l1" data-type="HTMLModule" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <body><a href="/static/content-berkeley-cs184x~2012_Fall/slides/overview.pdf">L1: Overview PDF Slides</a></body> </div> </div> <div class="vert vert-3" data-id="i4x://BerkeleyX/CS184.1x/discussion/discussion_6fbd3398c6dc"> <div class="xblock xblock-student_view xblock-student_view-discussion xmodule_display xmodule_DiscussionModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="discussion" data-request-token="725e38ba113011e585440a5fd5d593bd" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_discussion;_discussion_6fbd3398c6dc" data-type="InlineDiscussion" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "InlineDiscussion"} </script> <script aria-hidden="true" type="text/template" id="thread-template"> <article class="discussion-article" data-id="<%- id %>"> <div class="thread-wrapper" tabindex="-1"> <div class="forum-thread-main-wrapper"> <div class="thread-content-wrapper"></div> <div class="post-extended-content"> <ol class="responses js-marked-answer-list"></ol> </div> </div> <div class="post-extended-content"> <div class="response-count"/> <div class="add-response"> <button class="button add-response-btn"> <i class="icon fa fa-reply"></i> <span class="add-response-btn-text">Add A Response</span> </button> </div> <ol class="responses js-response-list"/> <div class="response-pagination"/> <div class="post-status-closed bottom-post-status" style="display: none"> This thread is closed. </div> <form class="discussion-reply-new" data-id="<%- id %>"> <h4>Post a response:</h4> <ul class="discussion-errors"></ul> <div class="reply-body" data-id="<%- id %>"></div> <div class="reply-post-control"> <a class="discussion-submit-post control-button" href="#">Submit</a> </div> </form> </div> </div> <div class="post-tools"> <a href="javascript:void(0)" class="forum-thread-expand"><span class="icon fa fa-plus"/> Expand discussion</a> <a href="javascript:void(0)" class="forum-thread-collapse"><span class="icon fa fa-minus"/> Collapse discussion</a> </div> </article> </script> <script aria-hidden="true" type="text/template" id="thread-show-template"> <div class="discussion-post"> <header> <div class="group-visibility-label"> <% if (obj.group_name) { %> <%- interpolate( gettext('This post is visible only to %(group_name)s.'), {group_name: obj.group_name}, true ) %> <% } else { %> <%- gettext('This post is visible to everyone.') %> <% } %> </div> <div class="post-header-content"> <h1><%- title %></h1> <p class="posted-details"> <% var timeAgoHtml = interpolate( '<span class="timeago" title="%(created_at)s">%(created_at)s</span>', {created_at: created_at}, true ); %> <%= interpolate( // Translators: post_type describes the kind of post this is (e.g. "question" or "discussion"); // time_ago is how much time has passed since the post was created (e.g. "4 hours ago") _.escape(gettext('%(post_type)s posted %(time_ago)s by %(author)s')), {post_type: thread_type, time_ago: timeAgoHtml, author: author_display}, true ) %> </p> <div class="post-labels"> <span class="post-label-pinned"><i class="icon fa fa-thumb-tack"></i><%- gettext("Pinned") %></span> <span class="post-label-reported"><i class="icon fa fa-flag"></i><%- gettext("Reported") %></span> <span class="post-label-closed"><i class="icon fa fa-lock"></i><%- gettext("Closed") %></span> </div> </div> <div class="post-header-actions post-extended-content"> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'post', primaryActions: ['vote', 'follow'], secondaryActions: ['pin', 'edit', 'delete', 'report', 'close'] } ) %> </div> </header> <div class="post-body"><%- body %></div> <% if (mode == "tab" && obj.courseware_url) { %> <% var courseware_title_linked = interpolate( '<a href="%(courseware_url)s">%(courseware_title)s</a>', {courseware_url: courseware_url, courseware_title: _.escape(courseware_title)}, true ); %> <div class="post-context"> <%= interpolate( _.escape(gettext('Related to: %(courseware_title_linked)s')), {courseware_title_linked: courseware_title_linked}, true ) %> </div> <% } %> </div> </script> <script aria-hidden="true" type="text/template" id="thread-edit-template"> <h1>Editing post</h1> <ul class="post-errors"></ul> <div class="forum-edit-post-form-wrapper"></div> <div class="form-row"> <label class="sr" for="edit-post-title">Edit post title</label> <input type="text" id="edit-post-title" class="edit-post-title" name="title" value="<%-title %>" placeholder="Title"> </div> <div class="form-row"> <div class="edit-post-body" name="body"><%- body %></div> </div> <input type="submit" id="edit-post-submit" class="post-update" value="Update post"> <a href="#" class="post-cancel">Cancel</a> </script> <script aria-hidden="true" type="text/template" id="thread-response-template"> <div class="discussion-response"></div> <a href="#" class="action-show-comments"> <%- interpolate('Show Comments (%(num_comments)s)', {num_comments: comments.length}, true) %> <i class="icon fa fa-caret-down"></i> </a> <ol class="comments"> <li class="new-comment"> <form class="comment-form" data-id="<%- wmdId %>"> <ul class="discussion-errors"></ul> <label class="sr" for="add-new-comment">Add a comment</label> <div class="comment-body" id="add-new-comment" data-id="<%- wmdId %>" data-placeholder="Add a comment"></div> <div class="comment-post-control"> <a class="discussion-submit-comment control-button" href="#">Submit</a> </div> </form> </li> </ol> </script> <script aria-hidden="true" type="text/template" id="thread-response-show-template"> <header> <div class="response-header-content"> <%= author_display %> <p class="posted-details"> <span class="timeago" title="<%= created_at %>"><%= created_at %></span> <% if (obj.endorsement) { %> - <%= interpolate( thread.get("thread_type") == "question" ? (endorsement.username ? "marked as answer %(time_ago)s by %(user)s" : "marked as answer %(time_ago)s") : (endorsement.username ? "endorsed %(time_ago)s by %(user)s" : "endorsed %(time_ago)s"), { 'time_ago': '<span class="timeago" title="' + endorsement.time + '">' + endorsement.time + '</span>', 'user': endorser_display }, true )%><% } %> </p> <div class="post-labels"> <span class="post-label-reported"><i class="icon fa fa-flag"></i>Reported</span> </div> </div> <div class="response-header-actions"> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'response', primaryActions: ['vote', thread.get('thread_type') == 'question' ? 'answer' : 'endorse'], secondaryActions: ['edit', 'delete', 'report'] } ) %> </div> </header> <div class="response-body"><%- body %></div> </script> <script aria-hidden="true" type="text/template" id="thread-response-edit-template"> <div class="edit-post-form"> <h1>Editing response</h1> <ul class="edit-post-form-errors"></ul> <div class="form-row"> <div class="edit-post-body" name="body" data-id="<%- id %>"><%- body %></div> </div> <input type="submit" id="edit-response-submit"class="post-update" value="Update response"> <a href="#" class="post-cancel">Cancel</a> </div> </script> <script aria-hidden="true" type="text/template" id="response-comment-show-template"> <div id="comment_<%- id %>"> <div class="response-body"><%- body %></div> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'comment', primaryActions: [], secondaryActions: ['edit', 'delete', 'report'] } ) %> <p class="posted-details"> <%= interpolate( 'posted %(time_ago)s by %(author)s', {'time_ago': '<span class="timeago" title="' + created_at + '">' + created_at + '</span>', 'author': author_display}, true )%> </p> <div class="post-labels"> <span class="post-label-reported"><i class="icon fa fa-flag"></i>Reported</span> </div> </div> </script> <script aria-hidden="true" type="text/template" id="response-comment-edit-template"> <div class="edit-post-form" id="comment_<%- id %>"> <h1>Editing comment</h1> <ul class="edit-comment-form-errors"></ul> <div class="form-row"> <div class="edit-comment-body" name="body" data-id="<%- id %>"><%- body %></div> </div> <input type="submit" id="edit-comment-submit" class="post-update" value="Update comment"> <a href="#" class="post-cancel">Cancel</a> </div> </script> <script aria-hidden="true" type="text/template" id="thread-list-item-template"> <li data-id="<%- id %>" class="forum-nav-thread<% if (typeof(read) != "undefined" && !read) { %> is-unread<% } %>"> <a href="#" class="forum-nav-thread-link"> <div class="forum-nav-thread-wrapper-0"> <% var icon_class, sr_text; if (thread_type == "discussion") { icon_class = "fa-comments"; sr_text = "discussion"; } else if (endorsed) { icon_class = "fa-check-square-o"; sr_text = "answered question"; } else { icon_class = "fa-question"; sr_text = "unanswered question"; } %> <span class="sr"><%= sr_text %></span> <i class="icon fa <%= icon_class %>"></i> </div><div class="forum-nav-thread-wrapper-1"> <span class="forum-nav-thread-title"><%- title %></span> <% var labels = ""; if (pinned) { labels += '<li class="post-label-pinned"><i class="icon fa fa-thumb-tack"></i>Pinned</li> '; } if (typeof(subscribed) != "undefined" && subscribed) { labels += '<li class="post-label-following"><i class="icon fa fa-star"></i>Following</li> '; } if (staff_authored) { labels += '<li class="post-label-by-staff"><i class="icon fa fa-user"></i>By: Staff</li> '; } if (community_ta_authored) { labels += '<li class="post-label-by-community-ta"><i class="icon fa fa-user"></i>By: Community TA</li> '; } if (labels != "") { print('<ul class="forum-nav-thread-labels">' + labels + '</ul>'); } %> </div><div class="forum-nav-thread-wrapper-2"> <span class="forum-nav-thread-votes-count">+<%= interpolate( '%(votes_up_count)s%(span_sr_open)s votes %(span_close)s', {'span_sr_open': '<span class="sr">', 'span_close': '</span>', 'votes_up_count': votes['up_count']}, true ) %></span> <span class="forum-nav-thread-comments-count <% if (unread_comments_count > 0) { %>is-unread<% } %>"> <% var fmt; // Counts in data do not include the post itself, but the UI should var data = { 'span_sr_open': '<span class="sr">', 'span_close': '</span>', 'unread_comments_count': unread_comments_count + (read ? 0 : 1), 'comments_count': comments_count + 1 }; if (unread_comments_count > 0) { fmt = '%(comments_count)s %(span_sr_open)scomments (%(unread_comments_count)s unread comments)%(span_close)s'; } else { fmt = '%(comments_count)s %(span_sr_open)scomments %(span_close)s'; } print(interpolate(fmt, data, true)); %> </span> </div> </a> </li> </script> <script aria-hidden="true" type="text/template" id="discussion-home"> <div class="discussion-article blank-slate"> <section class="home-header"> <span class="label">DISCUSSION HOME:</span> <h1 class="home-title">Foundations of Computer Graphics</h1> </section> <span class="label label-settings"> How to use edX discussions </span> <table class="home-helpgrid"> <tr class="helpgrid-row helpgrid-row-navigation"> <td class="row-title">Find discussions</td> <td class="row-item"> <i class="icon fa fa-reorder"></i> <span class="row-description">Focus in on specific topics</span> </td> <td class="row-item"> <i class="icon fa fa-search"></i> <span class="row-description">Search for specific posts </span> </td> <td class="row-item"> <i class="icon fa fa-sort"></i> <span class="row-description">Sort by date, vote, or comments</span> </td> </tr> <tr class="helpgrid-row helpgrid-row-participation"> <td class="row-title">Engage with posts</td> <td class="row-item"> <i class="icon fa fa-plus"></i> <span class="row-description">Upvote posts and good responses</span> </td> <td class="row-item"> <i class="icon fa fa-flag"></i> <span class="row-description">Report Forum Misuse</span> </td> <td class="row-item"> <i class="icon fa fa-star"></i> <span class="row-description">Follow posts for updates</span> </td> </tr> <tr class="helpgrid-row helpgrid-row-notification"> <td class="row-title">Receive updates</td> <td class="row-item-full" colspan="3"> <label for="email-setting-checkbox"> <span class="sr">Toggle Notifications Setting</span> <span class="notification-checkbox"> <input type="checkbox" id="email-setting-checkbox" class="email-setting" name="email-notification"/> <i class="icon fa fa-envelope"></i> </span> </label> <span class="row-description">Check this box to receive an email digest once a day notifying you about new, unread activity from posts you are following.</span> </td> </tr> </table> </div> </script> <script aria-hidden="true" type="text/template" id="search-alert-template"> <div class="search-alert" id="search-alert-<%- cid %>"> <div class="search-alert-content"> <p class="message"><%= message %></p> </div> <div class="search-alert-controls"> <a href="#" class="dismiss control control-dismiss"><i class="icon fa fa-remove"></i></a> </div> </div> </script> <script aria-hidden="true" type="text/template" id="new-post-template"> <form class="forum-new-post-form"> <ul class="post-errors" style="display: none"></ul> <div class="forum-new-post-form-wrapper"></div> <% if (cohort_options) { %> <div class="post-field group-selector-wrapper<% if (!is_commentable_cohorted) { %> disabled<% } %>" > <label class="field-label"> <span class="field-label-text"> Visible To: </span><select aria-describedby="field_help_visible_to" class="field-input js-group-select" name="group_id" <% if (!is_commentable_cohorted) { %>disabled<% } %>> <option value="">All Groups</option> <% _.each(cohort_options, function(opt) { %> <option value="<%= opt.value %>" <% if (opt.selected) { %>selected<% } %>><%- opt.text %></option> <% }); %> </select> </label><div class="field-help" id="field_help_visible_to"> Discussion admins, moderators, and TAs can make their posts visible to all students or specify a single cohort. </div> </div> <% } %> <div class="post-field"> <label class="field-label"> <span class="sr">Title:</span> <input aria-describedby="field_help_title" type="text" class="field-input js-post-title" name="title" placeholder="Title"> </label><span class="field-help" id="field_help_title"> Add a clear and descriptive title to encourage participation. </span> </div> <div class="post-field js-post-body editor" name="body" data-placeholder="Enter your question or comment"></div> <div class="post-options"> <label class="post-option is-enabled"> <input type="checkbox" name="follow" class="post-option-input js-follow" checked> <i class="icon fa fa-star"></i>follow this post </label> <% if (allow_anonymous) { %> <label class="post-option"> <input type="checkbox" name="anonymous" class="post-option-input js-anon"> post anonymously </label> <% } %> <% if (allow_anonymous_to_peers) { %> <label class="post-option"> <input type="checkbox" name="anonymous_to_peers" class="post-option-input js-anon-peers"> post anonymously to classmates </label> <% } %> </div> <div> <input type="submit" class="submit" value="Add Post"> <a href="#" class="cancel">Cancel</a> </div> </form> </script> <script aria-hidden="true" type="text/template" id="thread-type-template"> <div class="post-field"> <div class="field-label"> <span class="field-label-text"> Post type: </span><fieldset class="field-input"><legend class="sr">Post type:</legend> <input aria-describedby="field_help_post_type" type="radio" name="<%= form_id %>-post-type" class="post-type-input" id="<%= form_id %>-post-type-question" value="question"> <label for="<%= form_id %>-post-type-question" class="post-type-label"> <i class="icon fa fa-question"></i> Question </label> <input aria-describedby="field_help_post_type" type="radio" name="<%= form_id %>-post-type" class="post-type-input" id="<%= form_id %>-post-type-discussion" value="discussion" checked> <label for="<%= form_id %>-post-type-discussion" class="post-type-label"> <i class="icon fa fa-comments"></i> Discussion </label> </fieldset> </div><span class="field-help" id="field_help_post_type"> Questions raise issues that need answers. Discussions share ideas and start conversations. </span> </div> </script> <script aria-hidden="true" type="text/template" id="new-post-menu-entry-template"> <li role="menuitem" class="topic-menu-item"> <a href="#" class="topic-title" data-discussion-id="<%- id %>" data-cohorted="<%- is_cohorted %>"><%- text %></a> </li> </script> <script aria-hidden="true" type="text/template" id="new-post-menu-category-template"> <li role="menuitem" class="topic-menu-item"> <span class="topic-title"><%- text %></span> <ul role="menu" class="topic-submenu"><%= entries %></ul> </li> </script> <script aria-hidden="true" type="text/template" id="topic-template"> <div class="field-label"> <span class="field-label-text">Topic Area:</span><div class="field-input post-topic"> <a href="#" class="post-topic-button"> <span class="sr">Discussion topics; current selection is: </span> <span class="js-selected-topic"></span> <span class="drop-arrow" aria-hidden="true">▾</span> </a> <div class="topic-menu-wrapper"> <label class="topic-filter-label"> <span class="sr">Filter topics</span> <input aria-describedby="field_help_topic_area" type="text" class="topic-filter-input" placeholder="Filter topics"> </label> <ul class="topic-menu" role="menu"><%= topics_html %></ul> </div> </div> </div><span class="field-help" id="field_help_topic_area"> Add your post to a relevant topic to help others find it. </span> </script> <script type="text/template" id="forum-action-endorse"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-endorse" role="checkbox" aria-checked="false"> <span class="sr">Endorse</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Endorse</span> <span class="label-checked">Unendorse</span> </span> <span class="action-icon"><i class="icon fa fa-check"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-answer"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-answer" role="checkbox" aria-checked="false"> <span class="sr">Mark as Answer</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Mark as Answer</span> <span class="label-checked">Unmark as Answer</span> </span> <span class="action-icon"><i class="icon fa fa-check"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-follow"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-follow" role="checkbox" aria-checked="false"> <span class="sr">Follow</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Follow</span> <span class="label-checked">Unfollow</span> </span> <span class="action-icon"><i class="icon fa fa-star"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-vote"> <li class="actions-item"> <span aria-hidden="true" class="display-vote" > <span class="vote-count"></span> </span> <a href="#" class="action-button action-vote" role="checkbox" aria-checked="false"> <span class="sr">Vote for this post,&nbsp;</span> <span class="sr js-sr-vote-count"></span> <span class="action-label" aria-hidden="true"> <span class="vote-count"></span> </span> <span class="action-icon" aria-hidden="true"> <i class="icon fa fa-plus"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-report"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-report" role="checkbox" aria-checked="false"> <span class="sr">Report abuse</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Report</span> <span class="label-checked">Unreport</span> </span> <span class="action-icon"> <i class="icon fa fa-flag"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-pin"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-pin" role="checkbox" aria-checked="false"> <span class="sr">Pin</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Pin</span> <span class="label-checked">Unpin</span> </span> <span class="action-icon"> <i class="icon fa fa-thumb-tack"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-close"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-close" role="checkbox" aria-checked="false"> <span class="sr">Close</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Close</span> <span class="label-checked">Open</span> </span> <span class="action-icon"> <i class="icon fa fa-lock"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-edit"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-edit" role="button"> <span class="action-label">Edit</span> <span class="action-icon"><i class="icon fa fa-pencil"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-delete"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-delete" role="button"> <span class="action-label">Delete</span> <span class="action-icon"><i class="icon fa fa-remove"></i></span> </a> </li> </script> <script type="text/template" id="forum-actions"> <ul class="<%= contentType %>-actions-list"> <% _.each(primaryActions, function(action) { print(_.template($('#forum-action-' + action).html(), {})) }) %> <li class="actions-item is-visible"> <div class="more-wrapper"> <a href="javascript:void(0)" class="action-button action-more" role="button" aria-haspopup="true" aria-controls="action-menu-<%= contentId %>"> <span class="action-label">More</span> <span class="action-icon"><i class="icon fa fa-ellipsis-h"></i></span> </a> <div class="actions-dropdown" id="action-menu-<%= contentType %>" aria-expanded="false"> <ul class="actions-dropdown-list"> <% _.each(secondaryActions, function(action) { print(_.template($('#forum-action-' + action).html(), {})) }) %> </ul> </div> </div> </li> </ul> </script> <script aria-hidden="true" type="text/template" id="post-user-display-template"> <% if (username) { %> <a href="<%- user_url %>" class="username"><%- username %></a> <% if (is_community_ta) { %> <span class="user-label-community-ta">Community TA</span> <% } else if (is_staff) { %> <span class="user-label-staff">Staff</span> <% } %> <% } else { %> anonymous <% } %> </script> <div class="discussion-module" data-discussion-id="CS184_1x_2012_Fall_L1V2"> <a class="discussion-show control-button" href="javascript:void(0)" data-discussion-id="CS184_1x_2012_Fall_L1V2" role="button"><span class="show-hide-discussion-icon"></span><span class="button-text">Show Discussion</span></a> <a href="#" class="new-post-btn" role="button"><span class="icon fa fa-edit new-post-icon"></span>New Post</a> </div> </div> </div> </div> </div>
<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="725e38ba113011e585440a5fd5d593bd" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_vertical;_vertical_8693e8570c5b" data-block-type="vertical" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <div class="vert-mod"> <div class="vert vert-0" data-id="i4x://BerkeleyX/CS184.1x/video/L1V3_Online_Graphics_Overview_History"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="725e38ba113011e585440a5fd5d593bd" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_video;_L1V3_Online_Graphics_Overview_History" data-type="Video" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>L1V3: Online Graphics Overview: History</h2> <div id="video_i4x-BerkeleyX-CS184_1x-video-L1V3_Online_Graphics_Overview_History" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS184.1x/2012_Fall/xblock/i4x:;_;_BerkeleyX;_CS184.1x;_video;_L1V3_Online_Graphics_Overview_History/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://s3.amazonaws.com/berkeley-cs184x/videos/overview-history.mp4"], "autohideHtml5": false, "streams": "0.75:RpP8TVV7sCw,1.00:HD_59nFVzkU,1.25:rO765WfBD_I,1.50:FZ_d1fwLFX8", "saveStateUrl": "/courses/BerkeleyX/CS184.1x/2012_Fall/xblock/i4x:;_;_BerkeleyX;_CS184.1x;_video;_L1V3_Online_Graphics_Overview_History/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS184.1x/2012_Fall/xblock/i4x:;_;_BerkeleyX;_CS184.1x;_video;_L1V3_Online_Graphics_Overview_History/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS184_1x-video-L1V3_Online_Graphics_Overview_History" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS184_1x-video-L1V3_Online_Graphics_Overview_History"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS184_1x-video-L1V3_Online_Graphics_Overview_History" href="#after-transcript_i4x-BerkeleyX-CS184_1x-video-L1V3_Online_Graphics_Overview_History">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS184_1x-video-L1V3_Online_Graphics_Overview_History" href="#before-transcript_i4x-BerkeleyX-CS184_1x-video-L1V3_Online_Graphics_Overview_History">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://s3.amazonaws.com/berkeley-cs184x/videos/overview-history.mp4">Download video</a> </li> </ul> </div> </div> </div> <div class="vert vert-1" data-id="i4x://BerkeleyX/CS184.1x/html/video_l1v3"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="725e38ba113011e585440a5fd5d593bd" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_html;_video_l1v3" data-type="HTMLModule" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <body><a href="https://s3.amazonaws.com/berkeley-cs184x/transcripts/overview-history.txt">Video Transcript</a><br/><a href="https://s3.amazonaws.com/berkeley-cs184x/videos/overview-history_640.mp4">Low Resolution Video</a></body> </div> </div> <div class="vert vert-2" data-id="i4x://BerkeleyX/CS184.1x/html/video_l1"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="725e38ba113011e585440a5fd5d593bd" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_html;_video_l1" data-type="HTMLModule" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <body><a href="/static/content-berkeley-cs184x~2012_Fall/slides/overview.pdf">L1: Overview PDF Slides</a></body> </div> </div> <div class="vert vert-3" data-id="i4x://BerkeleyX/CS184.1x/discussion/discussion_caf35564d2a2"> <div class="xblock xblock-student_view xblock-student_view-discussion xmodule_display xmodule_DiscussionModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="discussion" data-request-token="725e38ba113011e585440a5fd5d593bd" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS184.1x;_discussion;_discussion_caf35564d2a2" data-type="InlineDiscussion" data-course-id="BerkeleyX/CS184.1x/2012_Fall"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "InlineDiscussion"} </script> <script aria-hidden="true" type="text/template" id="thread-template"> <article class="discussion-article" data-id="<%- id %>"> <div class="thread-wrapper" tabindex="-1"> <div class="forum-thread-main-wrapper"> <div class="thread-content-wrapper"></div> <div class="post-extended-content"> <ol class="responses js-marked-answer-list"></ol> </div> </div> <div class="post-extended-content"> <div class="response-count"/> <div class="add-response"> <button class="button add-response-btn"> <i class="icon fa fa-reply"></i> <span class="add-response-btn-text">Add A Response</span> </button> </div> <ol class="responses js-response-list"/> <div class="response-pagination"/> <div class="post-status-closed bottom-post-status" style="display: none"> This thread is closed. </div> <form class="discussion-reply-new" data-id="<%- id %>"> <h4>Post a response:</h4> <ul class="discussion-errors"></ul> <div class="reply-body" data-id="<%- id %>"></div> <div class="reply-post-control"> <a class="discussion-submit-post control-button" href="#">Submit</a> </div> </form> </div> </div> <div class="post-tools"> <a href="javascript:void(0)" class="forum-thread-expand"><span class="icon fa fa-plus"/> Expand discussion</a> <a href="javascript:void(0)" class="forum-thread-collapse"><span class="icon fa fa-minus"/> Collapse discussion</a> </div> </article> </script> <script aria-hidden="true" type="text/template" id="thread-show-template"> <div class="discussion-post"> <header> <div class="group-visibility-label"> <% if (obj.group_name) { %> <%- interpolate( gettext('This post is visible only to %(group_name)s.'), {group_name: obj.group_name}, true ) %> <% } else { %> <%- gettext('This post is visible to everyone.') %> <% } %> </div> <div class="post-header-content"> <h1><%- title %></h1> <p class="posted-details"> <% var timeAgoHtml = interpolate( '<span class="timeago" title="%(created_at)s">%(created_at)s</span>', {created_at: created_at}, true ); %> <%= interpolate( // Translators: post_type describes the kind of post this is (e.g. "question" or "discussion"); // time_ago is how much time has passed since the post was created (e.g. "4 hours ago") _.escape(gettext('%(post_type)s posted %(time_ago)s by %(author)s')), {post_type: thread_type, time_ago: timeAgoHtml, author: author_display}, true ) %> </p> <div class="post-labels"> <span class="post-label-pinned"><i class="icon fa fa-thumb-tack"></i><%- gettext("Pinned") %></span> <span class="post-label-reported"><i class="icon fa fa-flag"></i><%- gettext("Reported") %></span> <span class="post-label-closed"><i class="icon fa fa-lock"></i><%- gettext("Closed") %></span> </div> </div> <div class="post-header-actions post-extended-content"> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'post', primaryActions: ['vote', 'follow'], secondaryActions: ['pin', 'edit', 'delete', 'report', 'close'] } ) %> </div> </header> <div class="post-body"><%- body %></div> <% if (mode == "tab" && obj.courseware_url) { %> <% var courseware_title_linked = interpolate( '<a href="%(courseware_url)s">%(courseware_title)s</a>', {courseware_url: courseware_url, courseware_title: _.escape(courseware_title)}, true ); %> <div class="post-context"> <%= interpolate( _.escape(gettext('Related to: %(courseware_title_linked)s')), {courseware_title_linked: courseware_title_linked}, true ) %> </div> <% } %> </div> </script> <script aria-hidden="true" type="text/template" id="thread-edit-template"> <h1>Editing post</h1> <ul class="post-errors"></ul> <div class="forum-edit-post-form-wrapper"></div> <div class="form-row"> <label class="sr" for="edit-post-title">Edit post title</label> <input type="text" id="edit-post-title" class="edit-post-title" name="title" value="<%-title %>" placeholder="Title"> </div> <div class="form-row"> <div class="edit-post-body" name="body"><%- body %></div> </div> <input type="submit" id="edit-post-submit" class="post-update" value="Update post"> <a href="#" class="post-cancel">Cancel</a> </script> <script aria-hidden="true" type="text/template" id="thread-response-template"> <div class="discussion-response"></div> <a href="#" class="action-show-comments"> <%- interpolate('Show Comments (%(num_comments)s)', {num_comments: comments.length}, true) %> <i class="icon fa fa-caret-down"></i> </a> <ol class="comments"> <li class="new-comment"> <form class="comment-form" data-id="<%- wmdId %>"> <ul class="discussion-errors"></ul> <label class="sr" for="add-new-comment">Add a comment</label> <div class="comment-body" id="add-new-comment" data-id="<%- wmdId %>" data-placeholder="Add a comment"></div> <div class="comment-post-control"> <a class="discussion-submit-comment control-button" href="#">Submit</a> </div> </form> </li> </ol> </script> <script aria-hidden="true" type="text/template" id="thread-response-show-template"> <header> <div class="response-header-content"> <%= author_display %> <p class="posted-details"> <span class="timeago" title="<%= created_at %>"><%= created_at %></span> <% if (obj.endorsement) { %> - <%= interpolate( thread.get("thread_type") == "question" ? (endorsement.username ? "marked as answer %(time_ago)s by %(user)s" : "marked as answer %(time_ago)s") : (endorsement.username ? "endorsed %(time_ago)s by %(user)s" : "endorsed %(time_ago)s"), { 'time_ago': '<span class="timeago" title="' + endorsement.time + '">' + endorsement.time + '</span>', 'user': endorser_display }, true )%><% } %> </p> <div class="post-labels"> <span class="post-label-reported"><i class="icon fa fa-flag"></i>Reported</span> </div> </div> <div class="response-header-actions"> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'response', primaryActions: ['vote', thread.get('thread_type') == 'question' ? 'answer' : 'endorse'], secondaryActions: ['edit', 'delete', 'report'] } ) %> </div> </header> <div class="response-body"><%- body %></div> </script> <script aria-hidden="true" type="text/template" id="thread-response-edit-template"> <div class="edit-post-form"> <h1>Editing response</h1> <ul class="edit-post-form-errors"></ul> <div class="form-row"> <div class="edit-post-body" name="body" data-id="<%- id %>"><%- body %></div> </div> <input type="submit" id="edit-response-submit"class="post-update" value="Update response"> <a href="#" class="post-cancel">Cancel</a> </div> </script> <script aria-hidden="true" type="text/template" id="response-comment-show-template"> <div id="comment_<%- id %>"> <div class="response-body"><%- body %></div> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'comment', primaryActions: [], secondaryActions: ['edit', 'delete', 'report'] } ) %> <p class="posted-details"> <%= interpolate( 'posted %(time_ago)s by %(author)s', {'time_ago': '<span class="timeago" title="' + created_at + '">' + created_at + '</span>', 'author': author_display}, true )%> </p> <div class="post-labels"> <span class="post-label-reported"><i class="icon fa fa-flag"></i>Reported</span> </div> </div> </script> <script aria-hidden="true" type="text/template" id="response-comment-edit-template"> <div class="edit-post-form" id="comment_<%- id %>"> <h1>Editing comment</h1> <ul class="edit-comment-form-errors"></ul> <div class="form-row"> <div class="edit-comment-body" name="body" data-id="<%- id %>"><%- body %></div> </div> <input type="submit" id="edit-comment-submit" class="post-update" value="Update comment"> <a href="#" class="post-cancel">Cancel</a> </div> </script> <script aria-hidden="true" type="text/template" id="thread-list-item-template"> <li data-id="<%- id %>" class="forum-nav-thread<% if (typeof(read) != "undefined" && !read) { %> is-unread<% } %>"> <a href="#" class="forum-nav-thread-link"> <div class="forum-nav-thread-wrapper-0"> <% var icon_class, sr_text; if (thread_type == "discussion") { icon_class = "fa-comments"; sr_text = "discussion"; } else if (endorsed) { icon_class = "fa-check-square-o"; sr_text = "answered question"; } else { icon_class = "fa-question"; sr_text = "unanswered question"; } %> <span class="sr"><%= sr_text %></span> <i class="icon fa <%= icon_class %>"></i> </div><div class="forum-nav-thread-wrapper-1"> <span class="forum-nav-thread-title"><%- title %></span> <% var labels = ""; if (pinned) { labels += '<li class="post-label-pinned"><i class="icon fa fa-thumb-tack"></i>Pinned</li> '; } if (typeof(subscribed) != "undefined" && subscribed) { labels += '<li class="post-label-following"><i class="icon fa fa-star"></i>Following</li> '; } if (staff_authored) { labels += '<li class="post-label-by-staff"><i class="icon fa fa-user"></i>By: Staff</li> '; } if (community_ta_authored) { labels += '<li class="post-label-by-community-ta"><i class="icon fa fa-user"></i>By: Community TA</li> '; } if (labels != "") { print('<ul class="forum-nav-thread-labels">' + labels + '</ul>'); } %> </div><div class="forum-nav-thread-wrapper-2"> <span class="forum-nav-thread-votes-count">+<%= interpolate( '%(votes_up_count)s%(span_sr_open)s votes %(span_close)s', {'span_sr_open': '<span class="sr">', 'span_close': '</span>', 'votes_up_count': votes['up_count']}, true ) %></span> <span class="forum-nav-thread-comments-count <% if (unread_comments_count > 0) { %>is-unread<% } %>"> <% var fmt; // Counts in data do not include the post itself, but the UI should var data = { 'span_sr_open': '<span class="sr">', 'span_close': '</span>', 'unread_comments_count': unread_comments_count + (read ? 0 : 1), 'comments_count': comments_count + 1 }; if (unread_comments_count > 0) { fmt = '%(comments_count)s %(span_sr_open)scomments (%(unread_comments_count)s unread comments)%(span_close)s'; } else { fmt = '%(comments_count)s %(span_sr_open)scomments %(span_close)s'; } print(interpolate(fmt, data, true)); %> </span> </div> </a> </li> </script> <script aria-hidden="true" type="text/template" id="discussion-home"> <div class="discussion-article blank-slate"> <section class="home-header"> <span class="label">DISCUSSION HOME:</span> <h1 class="home-title">Foundations of Computer Graphics</h1> </section> <span class="label label-settings"> How to use edX discussions </span> <table class="home-helpgrid"> <tr class="helpgrid-row helpgrid-row-navigation"> <td class="row-title">Find discussions</td> <td class="row-item"> <i class="icon fa fa-reorder"></i> <span class="row-description">Focus in on specific topics</span> </td> <td class="row-item"> <i class="icon fa fa-search"></i> <span class="row-description">Search for specific posts </span> </td> <td class="row-item"> <i class="icon fa fa-sort"></i> <span class="row-description">Sort by date, vote, or comments</span> </td> </tr> <tr class="helpgrid-row helpgrid-row-participation"> <td class="row-title">Engage with posts</td> <td class="row-item"> <i class="icon fa fa-plus"></i> <span class="row-description">Upvote posts and good responses</span> </td> <td class="row-item"> <i class="icon fa fa-flag"></i> <span class="row-description">Report Forum Misuse</span> </td> <td class="row-item"> <i class="icon fa fa-star"></i> <span class="row-description">Follow posts for updates</span> </td> </tr> <tr class="helpgrid-row helpgrid-row-notification"> <td class="row-title">Receive updates</td> <td class="row-item-full" colspan="3"> <label for="email-setting-checkbox"> <span class="sr">Toggle Notifications Setting</span> <span class="notification-checkbox"> <input type="checkbox" id="email-setting-checkbox" class="email-setting" name="email-notification"/> <i class="icon fa fa-envelope"></i> </span> </label> <span class="row-description">Check this box to receive an email digest once a day notifying you about new, unread activity from posts you are following.</span> </td> </tr> </table> </div> </script> <script aria-hidden="true" type="text/template" id="search-alert-template"> <div class="search-alert" id="search-alert-<%- cid %>"> <div class="search-alert-content"> <p class="message"><%= message %></p> </div> <div class="search-alert-controls"> <a href="#" class="dismiss control control-dismiss"><i class="icon fa fa-remove"></i></a> </div> </div> </script> <script aria-hidden="true" type="text/template" id="new-post-template"> <form class="forum-new-post-form"> <ul class="post-errors" style="display: none"></ul> <div class="forum-new-post-form-wrapper"></div> <% if (cohort_options) { %> <div class="post-field group-selector-wrapper<% if (!is_commentable_cohorted) { %> disabled<% } %>" > <label class="field-label"> <span class="field-label-text"> Visible To: </span><select aria-describedby="field_help_visible_to" class="field-input js-group-select" name="group_id" <% if (!is_commentable_cohorted) { %>disabled<% } %>> <option value="">All Groups</option> <% _.each(cohort_options, function(opt) { %> <option value="<%= opt.value %>" <% if (opt.selected) { %>selected<% } %>><%- opt.text %></option> <% }); %> </select> </label><div class="field-help" id="field_help_visible_to"> Discussion admins, moderators, and TAs can make their posts visible to all students or specify a single cohort. </div> </div> <% } %> <div class="post-field"> <label class="field-label"> <span class="sr">Title:</span> <input aria-describedby="field_help_title" type="text" class="field-input js-post-title" name="title" placeholder="Title"> </label><span class="field-help" id="field_help_title"> Add a clear and descriptive title to encourage participation. </span> </div> <div class="post-field js-post-body editor" name="body" data-placeholder="Enter your question or comment"></div> <div class="post-options"> <label class="post-option is-enabled"> <input type="checkbox" name="follow" class="post-option-input js-follow" checked> <i class="icon fa fa-star"></i>follow this post </label> <% if (allow_anonymous) { %> <label class="post-option"> <input type="checkbox" name="anonymous" class="post-option-input js-anon"> post anonymously </label> <% } %> <% if (allow_anonymous_to_peers) { %> <label class="post-option"> <input type="checkbox" name="anonymous_to_peers" class="post-option-input js-anon-peers"> post anonymously to classmates </label> <% } %> </div> <div> <input type="submit" class="submit" value="Add Post"> <a href="#" class="cancel">Cancel</a> </div> </form> </script> <script aria-hidden="true" type="text/template" id="thread-type-template"> <div class="post-field"> <div class="field-label"> <span class="field-label-text"> Post type: </span><fieldset class="field-input"><legend class="sr">Post type:</legend> <input aria-describedby="field_help_post_type" type="radio" name="<%= form_id %>-post-type" class="post-type-input" id="<%= form_id %>-post-type-question" value="question"> <label for="<%= form_id %>-post-type-question" class="post-type-label"> <i class="icon fa fa-question"></i> Question </label> <input aria-describedby="field_help_post_type" type="radio" name="<%= form_id %>-post-type" class="post-type-input" id="<%= form_id %>-post-type-discussion" value="discussion" checked> <label for="<%= form_id %>-post-type-discussion" class="post-type-label"> <i class="icon fa fa-comments"></i> Discussion </label> </fieldset> </div><span class="field-help" id="field_help_post_type"> Questions raise issues that need answers. Discussions share ideas and start conversations. </span> </div> </script> <script aria-hidden="true" type="text/template" id="new-post-menu-entry-template"> <li role="menuitem" class="topic-menu-item"> <a href="#" class="topic-title" data-discussion-id="<%- id %>" data-cohorted="<%- is_cohorted %>"><%- text %></a> </li> </script> <script aria-hidden="true" type="text/template" id="new-post-menu-category-template"> <li role="menuitem" class="topic-menu-item"> <span class="topic-title"><%- text %></span> <ul role="menu" class="topic-submenu"><%= entries %></ul> </li> </script> <script aria-hidden="true" type="text/template" id="topic-template"> <div class="field-label"> <span class="field-label-text">Topic Area:</span><div class="field-input post-topic"> <a href="#" class="post-topic-button"> <span class="sr">Discussion topics; current selection is: </span> <span class="js-selected-topic"></span> <span class="drop-arrow" aria-hidden="true">▾</span> </a> <div class="topic-menu-wrapper"> <label class="topic-filter-label"> <span class="sr">Filter topics</span> <input aria-describedby="field_help_topic_area" type="text" class="topic-filter-input" placeholder="Filter topics"> </label> <ul class="topic-menu" role="menu"><%= topics_html %></ul> </div> </div> </div><span class="field-help" id="field_help_topic_area"> Add your post to a relevant topic to help others find it. </span> </script> <script type="text/template" id="forum-action-endorse"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-endorse" role="checkbox" aria-checked="false"> <span class="sr">Endorse</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Endorse</span> <span class="label-checked">Unendorse</span> </span> <span class="action-icon"><i class="icon fa fa-check"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-answer"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-answer" role="checkbox" aria-checked="false"> <span class="sr">Mark as Answer</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Mark as Answer</span> <span class="label-checked">Unmark as Answer</span> </span> <span class="action-icon"><i class="icon fa fa-check"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-follow"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-follow" role="checkbox" aria-checked="false"> <span class="sr">Follow</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Follow</span> <span class="label-checked">Unfollow</span> </span> <span class="action-icon"><i class="icon fa fa-star"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-vote"> <li class="actions-item"> <span aria-hidden="true" class="display-vote" > <span class="vote-count"></span> </span> <a href="#" class="action-button action-vote" role="checkbox" aria-checked="false"> <span class="sr">Vote for this post,&nbsp;</span> <span class="sr js-sr-vote-count"></span> <span class="action-label" aria-hidden="true"> <span class="vote-count"></span> </span> <span class="action-icon" aria-hidden="true"> <i class="icon fa fa-plus"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-report"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-report" role="checkbox" aria-checked="false"> <span class="sr">Report abuse</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Report</span> <span class="label-checked">Unreport</span> </span> <span class="action-icon"> <i class="icon fa fa-flag"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-pin"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-pin" role="checkbox" aria-checked="false"> <span class="sr">Pin</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Pin</span> <span class="label-checked">Unpin</span> </span> <span class="action-icon"> <i class="icon fa fa-thumb-tack"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-close"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-close" role="checkbox" aria-checked="false"> <span class="sr">Close</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Close</span> <span class="label-checked">Open</span> </span> <span class="action-icon"> <i class="icon fa fa-lock"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-edit"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-edit" role="button"> <span class="action-label">Edit</span> <span class="action-icon"><i class="icon fa fa-pencil"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-delete"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-delete" role="button"> <span class="action-label">Delete</span> <span class="action-icon"><i class="icon fa fa-remove"></i></span> </a> </li> </script> <script type="text/template" id="forum-actions"> <ul class="<%= contentType %>-actions-list"> <% _.each(primaryActions, function(action) { print(_.template($('#forum-action-' + action).html(), {})) }) %> <li class="actions-item is-visible"> <div class="more-wrapper"> <a href="javascript:void(0)" class="action-button action-more" role="button" aria-haspopup="true" aria-controls="action-menu-<%= contentId %>"> <span class="action-label">More</span> <span class="action-icon"><i class="icon fa fa-ellipsis-h"></i></span> </a> <div class="actions-dropdown" id="action-menu-<%= contentType %>" aria-expanded="false"> <ul class="actions-dropdown-list"> <% _.each(secondaryActions, function(action) { print(_.template($('#forum-action-' + action).html(), {})) }) %> </ul> </div> </div> </li> </ul> </script> <script aria-hidden="true" type="text/template" id="post-user-display-template"> <% if (username) { %> <a href="<%- user_url %>" class="username"><%- username %></a> <% if (is_community_ta) { %> <span class="user-label-community-ta">Community TA</span> <% } else if (is_staff) { %> <span class="user-label-staff">Staff</span> <% } %> <% } else { %> anonymous <% } %> </script> <div class="discussion-module" data-discussion-id="CS184_1x_2012_Fall_L1V3"> <a class="discussion-show control-button" href="javascript:void(0)" data-discussion-id="CS184_1x_2012_Fall_L1V3" role="button"><span class="show-hide-discussion-icon"></span><span class="button-text">Show Discussion</span></a> <a href="#" class="new-post-btn" role="button"><span class="icon fa fa-edit new-post-icon"></span>New Post</a> </div> </div> </div> </div> </div>
© All Rights Reserved

open